Module action

Module action 

Actions that describe changes to apply to a working tree.

Structs

ActionPlan
One self-consistent set of actions that fixes a [Diagnostic].
OverrideLineSelector
Identifies a specific override line for in-place edits.
TextRange
A byte range in a file.

Enums

Action
A change to apply to the working tree.
ChangelogAction
Edits to a debian/changelog.
Deb822Action
Edits to a deb822 file.
DebcargoAction
Edits to a debian/debcargo.toml file.
Dep3Action
Edits to a DEP-3 patch header.
DesktopIniAction
Edits to a freedesktop .desktop entry file.
FilesystemAction
Filesystem-level edits.
IndentPattern
Continuation-line indent pattern for multi-line deb822 field values.
LintianOverridesAction
Edits to a debian/source/lintian-overrides or debian/<pkg>.lintian-overrides file.
MaintscriptAction
Edits to a maintscript file.
MakefileAction
Edits to a Makefile (typically debian/rules).
ParagraphSelector
Identifies a paragraph in a deb822 file.
RunCommandAction
Run an external command that mutates the working tree.
SystemdAction
Edits to a systemd unit file.
WatchAction
Edits to a debian/watch file.
YamlAction
Edits to a YAML file.
YamlPathComponent
One step in a YamlAction path.