Module package_class

Module package_class 

Heuristics for classifying binary packages (transitional/meta-package). Heuristics for classifying binary packages.

Mirrors lintian’s Lintian::Processable::Installable::Class so that callers across the workspace can share the same definitions.

Functions

is_meta_package
Returns true if the binary package is probably a meta or task package.
is_transitional
Returns true if the binary package is probably transitional.