Utilities for reading and writing a Debian package working tree.
Re-exports
pub use trigger::ChangelogAspect;pub use trigger::Trigger;pub use trigger::WatchAspect;pub use workspace::Workspace;pub use workspace::compat_level;
Modules
- action
- Actions that describe changes to apply to a working tree.
- appliers
- Apply
action::Actions to a working tree. Apply [Action]s to a working tree. - fs_
workspace - A workspace implementation on a filesystem.
- trigger
- Allow notification on certain events.
- workspace
- Operate on a Debian package.
Workspace: an abstraction over the on-disk or in-editor state of a Debian source package.
Structs
- Version
- A Debian version string
Enums
- Error
- Errors that can occur while reading or writing workspace files.